ledger.Voucher (Voucher) — amici1

# `ledger.Voucher` (Voucher)

Voucher(id, user, journal, entry_date, voucher_date, accounting_period, number, narration)

Master tables : ledger.AllVouchers (Vouchers), ledger.PartnerVouchers (Vouchers)

Slave tables : ledger.MovementsByVoucher (Movements)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Author (user) : The author of this object. A pointer to lino.modlib.users.models.User.

- Journal (journal) : The journal into which this voucher has been booked. This is a mandatory pointer to a Journal instance.

- Entry date (entry_date) : The date of the journal entry, i.e. when this voucher is to journalized or booked.

- Voucher date (voucher_date) : The date on the voucher (i.e. when it has been issued by its emitter).

- Accounting period (accounting_period) : The accounting period to use when booking this voucher. The default value is determined from entry_date.

- No. (number) : The sequence number of this voucher in the journal.

- Narration (narration) : A short explanation which ascertains the subject matter of this journal entry.

- No. (number_with_year) : A text like „2019-12“.

- Name (name_column) : See `lino_xl.lib.ledger.models.Voucher.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.ledger.models.Voucher.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.ledger.models.Voucher.overview`.

Referenced from ledger.Movement.voucher

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
user | Author | The author of this object. A pointer to lino.modlib.users.models.User.
journal | Journal | The journal into which this voucher has been booked. This is a mandatory pointer to a Journal instance.
entry_date | Entry date | The date of the journal entry, i.e. when this voucher is to journalized or booked.
voucher_date | Voucher date | The date on the voucher (i.e. when it has been issued by its emitter).
accounting_period | Accounting period | The accounting period to use when booking this voucher. The default value is determined from entry_date.
number | No. | The sequence number of this voucher in the journal.
narration | Narration | A short explanation which ascertains the subject matter of this journal entry.
number_with_year | No. | A text like „2019-12“.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |